=========
CHANGELOG
=========

**************
Branch v.0.4.X
**************

Description::

    # This version branch was:
    # - complete rewrite of the project

0.4.0-dev0 (TODO:Still Work In Progress)
----------------------------------------
* Rewrite of the project::

    # Too much to write all details here
    # In the easy words of this version:
    # - I deleted pwbs 0.3.0-dev1 code
    # - I wrote pwbs code from zero again

**************
Branch v.0.3.X
**************

Description::

    # This version branch was:
    # - adding multi tasking

0.3.0-dev1 (22.12.2017)
-----------------------

* Release 8 on PyPi
* Added Multi Tasking

**************
Branch v.0.2.X
**************

Description::

    # This version branch was:
    # - Adding first mode of tasks
    # - Fixing some RST errors again
    # - Fixing some bugs [Hardcoded path and wrong default for one function]

0.2.0-dev3 (20.12.2017)
-----------------------

* Repaired Code Errors (Showing when using OS other then Windows)
* Repaired 4 Tests Failed on Linux
* Repaired pwbs.pwm.pwm_json (Wrong Default | Now Default is dict not list)


0.2.0-dev2 (16.12.2017)
-----------------------

* Release 7 on PyPi
* Repaired RST Errors

0.2.0-dev1 (16.12.2017)
-----------------------

* Release 6 on PyPi
* Added Single Tasking

**************
Branch v.0.1.X
**************

Description::

    # This version branch was:
    # - fixing some errors in repository and package basic documentation
    # - added some tests
    # - added some cli options

0.1.0-dev2 (13.12.2017-16.12.2017)
----------------------------------

* Release 5 on PyPi
* Added --new-config option as Working
* Added --config <file> option as Working

0.1.0-dev1 (12.12.2017-13.12.2017)
----------------------------------

* Release 4 on PyPi
* Added collective.checkdocs as setup requirement
* Repaired RST Errors
* Tests for pwm submodule and for pwbs module

**************
Branch v.0.0.X
**************

Description::

    # This Version Branch was first version of project PAiP Web Build System Edition 2
    # This was as Edition 2 by existance of my own PWBS project
    # I wanted to rewrite it to be more readable and better as well as add it to PyPi

0.0.1-dev4 (09.12.2017-12.12.2017)
----------------------------------

* Release 3 on PyPi
* Adding Command Interpreter
* Repairing setup.py Script
* Added Tox as Test Runner for checking with which version pwbs is compatible
* Added Command --help
* Added Command --verbose <mode>

0.0.1-dev3 (09.12.2017)
-----------------------

* Release 2 on PyPi
* Adding Baner

0.0.1-dev2 (09.12.2017)
-----------------------

* First Release in PyPi

0.0.1-dev0 (09.12.2017)
-----------------------

* First packaging